@@ -7,6 +7,17 @@ from scisel import *
 #average(
 
 
+# an simpler version of avgcyc
+def avgcyc(x,n):
+    """ calculate averaged cycle"""
+    xout = np.zeros([n+1]+list(np.shape(x)[1:]))
+    for ix in range(n):
+        xout[ix] = np.mean(x[ix::n],axis=0)
+    xout[n] = xout[0] 
+    return xout
+
+
+# a more extensive version of calculating a diurnal cycle
 def avgcycle(data, timeco = None, timewarp = None, cclose=False,skipnan=False):
     """ calculate averaged cycle
 input:
@@ -95,3 +106,7 @@ def avgglide(x,avlen):
     #     xout[j] = np.mean(x[max(0,(j-int(avlen/2.))):min((j+int(avlen/2.)),lenxout)],axis=0)
     # return (xout,)
 
+
+
+
+
